// Specify the URL of the CSV file
const csvUrl =
  'https://raw.githubusercontent.com/nawindodda/Assignment-2/main/india_population.csv';

// Load data from the CSV file using D3
d3.csv(csvUrl)
  .then(function (data) {
    // Convert string values to numbers if needed
    data.forEach(function (d) {
      d.Year = +d.Year; // Corrected property name
      d.Value = +d.Value; // Corrected property name
    });

    // Set up dimensions for the chart
    const width = 800;
    const height = 400;
    const margin = {
      top: 20,
      right: 20,
      bottom: 50,
      left: 50,
    };
    const innerWidth = width - margin.left - margin.right;
    const innerHeight = height - margin.top - margin.bottom;

    // Create SVG element
    const svg = d3
      .select('body')
      .append('svg')
      .attr('id', 'areachart') // Added id to select the SVG later
      .attr('width', width)
      .attr('height', height);

    // Create scales
    const xScale = d3
      .scaleLinear()
      .domain(d3.extent(data, (d) => d.Year)) // Corrected property name
      .range([margin.left, innerWidth]);

    const yScale = d3
      .scaleLinear()
      .domain([0, d3.max(data, (d) => d.Value)]) // Corrected property name
      .range([innerHeight, margin.top]);

    // Create area generator
    const area = d3
      .area()
      .x((d) => xScale(d.Year)) // Corrected property name
      .y0(innerHeight)
      .y1((d) => yScale(d.Value)); // Corrected property name

    // Append area to SVG
    svg
      .append('path')
      .datum(data)
      .attr('fill', 'steelblue')
      .attr('d', area);

    // Create axes
    const xAxis = d3
      .axisBottom(xScale)
      .tickFormat(d3.format('d'));
    const yAxis = d3.axisLeft(yScale);

    // Append axes to SVG
    svg
      .append('g')
      .attr('transform', `translate(0, ${innerHeight})`)
      .call(xAxis)
      // X-axis label
      .append('text')
      .attr('x', innerWidth / 2)
      .attr('y', margin.bottom - 10)
      .attr('fill', '#000')
      .style('text-anchor', 'middle')
      .style('font-size', 20)
      .text('Year'); // Corrected axis label

    svg
      .append('g')
      .attr('transform', `translate(${margin.left}, 0)`)
      .call(yAxis)
      // Y-axis label
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('x', -innerHeight / 2)
      .attr('y', -margin.left + 15)
      .attr('fill', '#000')
      .style('text-anchor', 'middle')
      .style('font-size', 20)
      .text('Population'); // Corrected axis label
  })
  .catch(function (error) {
    console.log('Error loading data: ', error);
  });
